==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ja.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "アクティビティ",
    "Error loading activities" : "アクティビティ読み込みエラー",
    "No activities" : "アクティビティなし",
    "Load more activities" : "さらにアクティビティを読み込み",
    "Copied!" : "コピーされました！",
    "Not supported!" : "サポートされていません！",
    "Press ⌘-C to copy." : "⌘+Cを押してコピーします。",
    "Press Ctrl-C to copy." : "Ctrl+Cを押してコピーします。",
    "{name} (invisible)" : "{name} (非表示)",
    "{name} (restricted)" : "{name} (制限)",
    "in {path}" : "{path}に",
    "This stream will show events like additions, changes & shares" : "このタイムラインには、追加、変更、共有が表示されます。",
    "There are no events for this filter" : "このフィルターで表示されるイベントはありません。",
    "Today" : "今日",
    "Yesterday" : "昨日",
    "Activity" : "アクティビティ",
    "Personal activity feed for %s" : "\"%s\" の個人アクティビティフィード",
    "Your feed URL is invalid" : "フィードURLが無効です",
    "Your settings have been updated." : "設定を更新しました。",
    "Mail" : "メール",
    "Stream" : "ストリーム",
    "All activities" : "すべてのアクティビティ",
    "By others" : "他人から",
    "By you" : "あなたによって",
    "\"remote user\"" : "\"リモートユーザー\"",
    "Activity notification" : "アクティビティ通知",
    ", " : ", ",
    "%s and %s" : "%s と %s",
    "Hello %s," : "%s さんこんにちは、",
    "You are receiving this email because the following things happened at %s" : "%s で以下のような更新がありました。このメールはその内容をお知らせします。",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* と その他 %n 個"],
    "List your own actions in the stream" : "ストリーム上にあなたの操作を表示する",
    "Notify about your own actions via email" : "メールで自分のアクションを通知する",
    "You need to set up your email address before you can receive notification emails." : "通知メールを受け取る前にメールアドレスを設定してください。",
    "Send emails:" : "メールを送信:",
    "Hourly" : "1時間ごと",
    "Daily" : "毎日",
    "Weekly" : "毎週",
    "Activity feed" : "アクティビティフィード",
    "Enable RSS feed" : "RSSフィードを有効にする",
    "No activity yet" : "アクティビティなし",
    "No more events to load" : "これ以上読み込むイベントはありません",
    "Files" : "ファイル"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ja.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "アクティビティ",
    "An error occurred while loading activities" : "アクティビティを読み込む際にエラーが発生しました",
    "No activity yet" : "アクティビティなし",
    "Load more activities" : "さらにアクティビティを読み込み",
    "Copied!" : "コピーされました！",
    "Not supported!" : "サポートされていません！",
    "Press ⌘-C to copy." : "⌘+Cを押してコピーします。",
    "Press Ctrl-C to copy." : "Ctrl+Cを押してコピーします。",
    "{name} (invisible)" : "{name} (非表示)",
    "{name} (restricted)" : "{name} (制限)",
    "in {path}" : "{path}に",
    "This stream will show events like additions, changes & shares" : "このタイムラインには、追加、変更、共有が表示されます。",
    "There are no events for this filter" : "このフィルターで表示されるイベントはありません。",
    "Today" : "今日",
    "Yesterday" : "昨日",
    "Personal activity feed for %s" : "\"%s\" の個人アクティビティフィード",
    "Your feed URL is invalid" : "フィードURLが無効です",
    "Your settings have been updated." : "設定を更新しました。",
    "Settings have been updated." : "設定を更新しました。",
    "Mail" : "メール",
    "Stream" : "ストリーム",
    "All activities" : "すべてのアクティビティ",
    "By others" : "自分以外",
    "By you" : "自分",
    "\"remote user\"" : "\"リモートユーザー\"",
    "Hello %s" : "%s さん、こんにちは",
    "Hello %s," : "%s さんこんにちは、",
    "There was some activity at %s" : "%s　にアクティビティがありました。",
    "_and %n more _::_and %n more _" : ["および他 %n "],
    "Activity notification" : "アクティビティ通知",
    ", " : ", ",
    "%s and %s" : "%s と %s",
    "Activity" : "アクティビティ",
    "Activity feed" : "アクティビティフィード",
    "Configure the default activity settings for new users." : "新しいユーザーのデフォルトのアクティビティ設定を構成します。",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "メール通知を受け取るアクティビティと、アクティビティアプリストリームに表示するアクティビティを選択します。",
    "List your own actions in the stream" : "ストリーム上にあなたの操作を表示する",
    "Notify about your own actions via email" : "メールで自分のアクションを通知する",
    "You need to set up your email address before you can receive notification emails." : "通知メールを受け取る前にメールアドレスを設定してください。",
    "Send emails:" : "メールを送信:",
    "Hourly" : "1時間ごと",
    "Daily" : "毎日",
    "Weekly" : "毎週",
    "Settings" : "設定",
    "Enable RSS feed" : "RSSフィードを有効にする",
    "No more events to load" : "これ以上読み込むイベントはありません",
    "Files" : "ファイル"
},
"nplurals=1; plural=0;");
